@@ -4,7 +4,7 @@ use 5.7.3;
 use strict;
 use warnings;
 
-our $VERSION = '0.086';
+our $VERSION = '0.09';
 
 
 1;
@@ -181,6 +181,14 @@ C<PGUSER> and C<PGPASSWORD> environment variables will achieve this.
   AxAddPlugin Apache::AxKit::Plugin::AddXSLParams::Request
   PerlSetVar AxAddXSLParamGroups "HTTPHeaders"
 
+  # If you want a different language than English, you need to
+  # translate i18n.en.xml and replace nb with your language
+  # code. These two directives are optional, you don't need any if you
+  # want English.
+  AxAddPlugin Apache::AxKit::Plugin::Param::Expr
+  PerlAddVar AxParamExpr neg.lang '"nb"'
+
+
   # Authentication
   PerlModule Apache::AxKit::Plugin::BasicAuth
   AxAddPlugin Apache::AxKit::Plugin::BasicSession
@@ -264,7 +272,11 @@ C<PGUSER> and C<PGPASSWORD> environment variables will achieve this.
   PerlSetVar TABOODemoDataStore DB_File
   PerlSetVar TABOODemoArgs      "FileName => /tmp/taboodemo-session"
   PerlSetVar TABOODemoLoginScript /login.xsp
+  # If you like to keep people logged in over a longer time, you may 
+  # extend their session, eg:
+  PerlSetVar TABOODemoCookieExpires +14d
 
+  
 
   # /////////////////////////////
 
